@@ -67,8 +67,7 @@ class RSA(object):
 				loader = Console.Loader(f"Generating key {self.directory}")
 			if Files.exists(directory): 
 				loader.stop(success=False)
-				response["error"] = f"Key [{directory}] already exists."
-				return response
+				return Response.error(f"Key [{directory}] already exists.")
 		else:
 			if log_level >= 0: loader = Console.Loader("Generating key")
 		
@@ -142,9 +141,9 @@ class RSA(object):
 		except ValueError as e:
 			self.public_key_object = None
 			if "Padding is incorrect" in str(e):
-				response["error"] = "Provided an incorrect passphrase."
-			else: response["error"] = f"ValueError: {e}"
-			return response
+				return Response.error("Provided an incorrect passphrase.")
+			else: 
+				return Response.error(f"ValueError: {e}")
 		
 		# response.
 		return Response.success("Successfully loaded the key pair.")
@@ -165,8 +164,9 @@ class RSA(object):
 			except ValueError as e:
 				self.private_key_object = None
 				if "Padding is incorrect" in str(e):
-					response["error"] = "Provided an incorrect passphrase."
-				else: response["error"] = f"ValueError: {e}"
+					return Response.error("Provided an incorrect passphrase.")
+				else: 
+					return Response.error(f"ValueError: {e}")
 				return response
 		else:
 			try:
@@ -174,8 +174,9 @@ class RSA(object):
 			except ValueError as e:
 				self.private_key_object = None
 				if "Padding is incorrect" in str(e):
-					response["error"] = "Provided an incorrect passphrase."
-				else: response["error"] = f"ValueError: {e}"
+					return Response.error("Provided an incorrect passphrase.")
+				else: 
+					return Response.error(f"ValueError: {e}")
 				return response
 		
 		# response.
@@ -201,12 +202,9 @@ class RSA(object):
 				os.system(f"rm -fr {private_key}")
 			self.passphrase = passphrase
 			if self.passphrase == '""': self.passphrase = None
-			response["success"] = True
-			response["message"] = f"Successfully edit the passphrase of key [{self.id}]."
-			return response
+			return Response.success(f"Successfully edit the passphrase of key [{self.id}].")
 		else:
-			response["error"] = f"Failed to edit the passphrase of key [{self.id}], error: {output}."
-			return response
+			return Response.error(f"Failed to edit the passphrase of key [{self.id}], error: {output}.")
 
 		#
 	# encrypting.
@@ -223,13 +221,12 @@ class RSA(object):
 		if layers-1 > 0:
 			return self.encrypt_string(encrypted, layers=layers-1)
 		else:
-			response["success"] = True
-			response["message"] = f"Successfully encrypted the string."
+			
 			if decode:
-				response["encrypted"] = encrypted.decode()
-			else:
-				response["encrypted"] = encrypted
-			return response
+				encrypted = encrypted.decode()
+			return Response.success(f"Successfully encrypted the string.", {
+				"encrypted":encrypted
+			})
 
 		#
 	def encrypt_file(self, path, layers=1):
@@ -285,11 +282,9 @@ class RSA(object):
 			# checks.
 			file_path = FilePath(path)
 			if not file_path.exists():
-				response["error"] = f"Directory [{path}] does not exist."
-				return response
+				return Response.error(f"Directory [{path}] does not exist.")
 			if not file_path.directory():
-				response["error"] = f"Directory path [{path}] is not a directory."
-				return response
+				return Response.error(f"Directory path [{path}] is not a directory.")
 
 			# create zip.
 			if path[len(path)-1] == "/": zip_path = path[:-1]
@@ -304,9 +299,9 @@ class RSA(object):
 				file_path.delete(forced=True)
 				return response
 			else:
-				response["error"] = f"Failed to encrypted directory [{path}]."
 				zip.file_path.delete(forced=True)
-				return response
+				return Response.error(f"Failed to encrypted directory [{path}].")
+				
 
 		#
 	# decrypting.
@@ -324,13 +319,10 @@ class RSA(object):
 		if layers-1 > 0:
 			return self.decrypt_string(decrypted, layers=layers-1)
 		else:
-			response["success"] = True
-			response["message"] = f"Successfully encrypted the string."
-			if decode:
-				response["decrypted"] = decrypted.decode()
-			else:
-				response["decrypted"] = decrypted
-			return response
+			if decode: decrypted = decrypted.decode()
+			return Response.success(f"Successfully decrypted the string.", {
+				"decrypted":decrypted,
+			})
 
 		#
 	def decrypt_file(self, path, layers=1):
@@ -348,9 +340,7 @@ class RSA(object):
 		if layers-1 > 0:
 			return self.decrypt_file(path, layers=layers-1)
 		else:
-			response["success"] = True
-			response["message"] = f"Successfully decrypted file [{path}]."
-			return response
+			return Response.success(f"Successfully decrypted file [{path}].")
 
 		#
 	def decrypt_directory(self, path, recursive=False, layers=1):
@@ -380,9 +370,7 @@ class RSA(object):
 			if layers-1 > 0:
 				return self.decrypt_directory(path, recursive=True, layers=layers-1)
 			else:
-				response["success"] = True
-				response["message"] = f"Successfully decrypted directory [{path}] (recursively)."
-				return response		
+				return Response.success(f"Successfully decrypted directory [{path}] (recursively).")
 
 		# decrypt the encrypted.zip file.
 		else:
@@ -396,26 +384,21 @@ class RSA(object):
 			else: zip_path = str(path)
 			zip_path = f'{zip_path}.encrypted.zip'
 			if not Files.exists(zip_path):
-				response["error"] = f"System encrypted zip [{path}] does not exist."
-				return response
+				return Response.error(f"System encrypted zip [{path}] does not exist.")
 			
 			# decrypt zip.
 			response = self.decrypt_file(zip_path, layers=layers)
 			if response["error"] != None:
-				response["error"] = f"Failed to decrypted directory [{path}]."
-				return response
+				return Response.error(f"Failed to decrypted directory [{path}].")
 
 			# extract zip.
 			zip = Zip(path=zip_path)
 			zip.extract(base=None)
 			if Files.exists(path):
-				response["success"] = True
-				response["message"] = f"Successfully decrypted directory [{path}]."
 				zip.file_path.delete(forced=True)
-				return response
+				return Response.success(f"Successfully decrypted directory [{path}].")
 			else:
-				response["error"] = f"Failed to decrypted directory [{path}]."
-				return response
+				return Response.error(f"Failed to decrypted directory [{path}].")
 
 		#
 	# system functions.
@@ -579,9 +562,7 @@ class EncryptedDictionary(Dictionary):
 			if response["error"] != None: return response
 
 		# success.
-		response["success"] = True
-		response["message"] = f"Successfully initialized encrypted dictionary [{self.file_path.path}]."
-		return response
+		return Response.success(f"Successfully initialized encrypted dictionary [{self.file_path.path}].")
 		#
 	def load(self):
 
@@ -594,13 +575,10 @@ class EncryptedDictionary(Dictionary):
 		# handle.
 		try:
 			self.dictionary = json.loads(decrypted)
-			response["success"] = True
-			response["message"] = f"Successfully loaded encrypted dictionary [{self.file_path.path}]."
-			return response
+			return Response.success(f"Successfully loaded encrypted dictionary [{self.file_path.path}].")
 		except: 
 			self.dictionary = None
-			response["error"] = f"Failed to load encrypted dictionary [{self.file_path.path}]."
-			return response
+			return Response.error(f"Failed to load encrypted dictionary [{self.file_path.path}].")
 
 		#
 	def save(self, dictionary=None):
@@ -616,24 +594,19 @@ class EncryptedDictionary(Dictionary):
 		# handle.
 		try:
 			self._file_.save(encrypted)
-			response["success"] = True
-			response["message"] = f"Successfully saved encrypted dictionary [{self.file_path.path}]."
-			return response
+			return Response.success(f"Successfully saved encrypted dictionary [{self.file_path.path}].")
 		except: 
 			self.dictionary = None
-			response["error"] = f"Failed to save encrypted dictionary [{self.file_path.path}]."
-			return response
+			return Response.error(f"Failed to save encrypted dictionary [{self.file_path.path}].")
 
 		#
 	def check(self, default=None, save=True):
 
 		# checks.
 		if not isinstance(default, dict): 
-			response["error"] = "Parameter [default] must be a dictionary."
-			return response
+			return Response.error("Parameter [default] must be a dictionary.")
 		if not isinstance(self.dictionary, dict): 
-			response["error"] = "The dictionary must be initialized & loaded."
-			return response
+			return Response.error("The dictionary must be initialized & loaded.")
 
 		# handle.
 		try:
@@ -641,18 +614,14 @@ class EncryptedDictionary(Dictionary):
 			self._dictionary_.dictionary = self.dictionary
 			self.dictionary = self._dictionary_.check(default=default)
 		except:
-			response["error"] = "Failed to check the loaded dictionary."
-			return response
+			return Response.error("Failed to check the loaded dictionary.")
 
 		# save.
 		if save and old != self.dictionary:
 			response = self.save()
 			if response["error"] != None: 
-				response["error"] = "Failed to check the loaded dictionary, error: "+response['error']
-				return response
+				return Response.error("Failed to check the loaded dictionary, error: "+response['error'])
 
 		# success.
-		response["success"] = True
-		response["message"] = f"Successfully saved encrypted dictionary [{self.file_path.path}]."
-		return response
+		return Response.success(f"Successfully saved encrypted dictionary [{self.file_path.path}].")
 		
